BillingCountryPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BillingCountryPlatform
Implementers

Constructors

BillingCountryPlatform()
Constructs a BillingCountryPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCountryCode() Future<String?>
Returns the raw billing storefront country code reported by the native platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BillingCountryPlatform
The default instance of BillingCountryPlatform to use.
getter/setter pair